var gulp = require('gulp');
var del = require('del');
var uglify = require('gulp-uglify');
var cleanCss = require('gulp-clean-css');
var rename = require('gulp-rename');
var concat = require('gulp-concat');
var plugins = require('gulp-load-plugins')();
var runSequence = require('run-sequence');

var pkg = require('./package.json');
var dirs = pkg.directories;

//编译sass，压缩，重命名main.css,并拷贝到dist/css中
gulp.task('compile:css', function () {
    var banner = '/*! ' + pkg.name + ' v' + pkg.version +
        ' | ' + pkg.license.type + ' License' +
        ' | ' + pkg.homepage + ' */\n\n';
    gulp.src(dirs.src + "/css/style.css")
        .pipe(cleanCss())
        .pipe(rename('style.min.css'))
        .pipe(plugins.header(banner))
        .pipe(plugins.autoprefixer({
            browsers: ['last 2 versions', 'ie >= 8', '> 1%'],
            cascade: false
        }))
        .pipe(gulp.dest(dirs.dist + "/css"));
});

// ---------------------------------------------------------------------
// | js file tasks                                                      |
// ---------------------------------------------------------------------

//校验js
gulp.task('lint:js', function () {
    return gulp.src([
        'gulpfile.js',
        dirs.src + '/js/*.js'
    ]).pipe(plugins.jscs())
        .pipe(plugins.jshint())
        .pipe(plugins.jshint.reporter('jshint-stylish'))
        .pipe(plugins.jshint.reporter('fail'));
});

//合并,压缩，重命名,并拷贝到dist/js中
gulp.task('compile:js', function () {
    gulp.src(dirs.src + "/js/*.js")
        .pipe(concat('tree.js'))
        .pipe(rename({suffix: '.min'}))
        .pipe(uglify({mangle: false}))
        .pipe(gulp.dest(dirs.dist + "/js"));
});

gulp.task('compile', [
    'compile:css',
    'compile:js'
]);

// ---------------------------------------------------------------------
// | copy files tasks                                                      |
// ---------------------------------------------------------------------
gulp.task('copy', [
    'copy:html'
]);

gulp.task('copy:html', function () {
    gulp.src(dirs.src + '/*.html')
        .pipe(gulp.dest(dirs.dist));
});

gulp.task('watch', function () {
    gulp.watch(dirs.src + '/js/*.js', ['compile:js']);
    gulp.watch(dirs.src + '/css/*.css', ['compile:css']);
    gulp.watch(dirs.src + '/*.html', ['copy:html']);
});

gulp.task('clean', function () {
    return del([dirs.dist], {'force': true});
});


gulp.task('build', function (done) {
    return runSequence(
        ['clean', 'lint:js'],
        'compile', 'copy',
        done);
});

gulp.task('startup', ['build', 'watch'], function () {
});

gulp.task('default', ['build']);
